@@ -298,6 +298,8 @@ class MQLInterface(BaseInterface):  # noqa: D
         limit: Optional[str] = None,
         cache_mode: Optional[CacheMode] = None,
         as_table: Optional[str] = None,
+        time_series: bool = True,
+        result_format: Optional[str] = None,
     ) -> Dict[str, Any]:
         return {
             "modelKey": {
@@ -317,6 +319,8 @@ class MQLInterface(BaseInterface):  # noqa: D
             "limit": limit,
             "cacheMode": (CacheMode.default() if cache_mode is None else cache_mode).name,
             "asTable": as_table,
+            "timeSeries": time_series,
+            "resultFormat": result_format,
         }
 
     def drop_materialization(  # noqa: D
@@ -535,76 +539,51 @@ class MQLInterface(BaseInterface):  # noqa: D
     ) -> str:
         """Implements CreateMqlQuery mutation in MQL/GQL"""
 
-        if time_granularity:
-            query = gql(
-                """
-                mutation CreateMqlQueryMutation(
-                    $modelKey: ModelKeyInput,
-                    $metrics: [String!],
-                    $groupBy: [String!],
-                    $whereConstraint: String,
-                    $timeConstraint: String,
-                    $timeGranularity: TimeGranularity,
-                    $order: [String!],
-                    $limit: LimitInput,
-                    $cacheMode: CacheMode,
-                    $asTable: String
-                ) {
-                    createMqlQuery(
-                        input: {
-                            modelKey: $modelKey,
-                            metrics: $metrics,
-                            groupBy: $groupBy,
-                            whereConstraint: $whereConstraint,
-                            timeConstraint: $timeConstraint,
-                            timeGranularity: $timeGranularity,
-                            order: $order,
-                            limit: $limit,
-                            cacheMode: $cacheMode,
-                            asTable: $asTable,
-                            addTimeSeries: true,
-                            resultFormat: TFD
-                        }
-                    ) {
-                        id
-                    }
-                }
-                """
-            )
+        # Unless we are requesting multiple metrics, include the post-processor required by the UI
+        # so that users are able to visualize the results in the query logs
+        if len(metrics) > 1:
+            time_series = False
+            result_format = None
         else:
-            query = gql(
-                """
-                mutation CreateMqlQueryMutation(
-                    $modelKey: ModelKeyInput,
-                    $metrics: [String!],
-                    $groupBy: [String!],
-                    $whereConstraint: String,
-                    $timeConstraint: String,
-                    $order: [String!],
-                    $limit: LimitInput,
-                    $cacheMode: CacheMode,
-                    $asTable: String
-                ) {
-                    createMqlQuery(
-                        input: {
-                            modelKey: $modelKey,
-                            metrics: $metrics,
-                            groupBy: $groupBy,
-                            whereConstraint: $whereConstraint,
-                            timeConstraint: $timeConstraint,
-                            order: $order,
-                            limit: $limit,
-                            cacheMode: $cacheMode,
-                            asTable: $asTable,
-                            addTimeSeries: true,
-                            resultFormat: TFD
-                        }
-                    ) {
-                        id
+            time_series = True
+            result_format = "TFD"
+        query = gql(
+            """
+            mutation CreateMqlQueryMutation(
+                $modelKey: ModelKeyInput,
+                $metrics: [String!],
+                $groupBy: [String!],
+                $whereConstraint: String,
+                $timeConstraint: String,
+                $timeGranularity: TimeGranularity,
+                $order: [String!],
+                $limit: LimitInput,
+                $cacheMode: CacheMode,
+                $asTable: String,
+                $timeSeries: Boolean,
+                $resultFormat: ResultFormat,
+            ) {
+                createMqlQuery(
+                    input: {
+                        modelKey: $modelKey,
+                        metrics: $metrics,
+                        groupBy: $groupBy,
+                        whereConstraint: $whereConstraint,
+                        timeConstraint: $timeConstraint,
+                        timeGranularity: $timeGranularity,
+                        order: $order,
+                        limit: $limit,
+                        cacheMode: $cacheMode,
+                        asTable: $asTable,
+                        addTimeSeries: $timeSeries,
+                        resultFormat: $resultFormat
                     }
+                ) {
+                    id
                 }
-                """
-            )
+            }
+            """
+        )
 
         params = self.__common_query_input_params(
             model_key=model_key,
@@ -617,6 +596,8 @@ class MQLInterface(BaseInterface):  # noqa: D
             limit=limit,
             cache_mode=cache_mode,
             as_table=as_table,
+            time_series=time_series,
+            result_format=result_format,
         )
 
         return self.execute(query, variable_values=params)["createMqlQuery"]["id"]
